@@ -24,7 +24,7 @@
 #include <time.h>
 #include "srtypes.h"
 #include "rip_manager.h"
-#include "util.h"
+#include "mchar.h"
 #include "filelib.h"
 #include "debug.h"
 
@@ -62,7 +62,8 @@ time_t				m_stop_time = 0;
  * call as well, but i needed this for window'd apps.
  */
 
-int main(int argc, char* argv[])
+int
+main (int argc, char* argv[])
 {
     int ret;
     time_t temp_time;
@@ -105,7 +106,8 @@ int main(int argc, char* argv[])
     return 0;
 }
 
-void catch_sig(int code)
+void
+catch_sig(int code)
 {
     if (!m_dont_print)
 	fprintf(stderr, "\n");
@@ -120,7 +122,8 @@ void catch_sig(int code)
  * is for handling the pretty formating stuff otherwise it could be
  * much smaller.
  */
-void print_status()
+void
+print_status()
 {
     char status_str[128];
     char filesize_str[64];
@@ -197,7 +200,8 @@ void print_status()
  * for the most part this function just checks what kind of message we got
  * and prints out stuff to the screen.
  */
-void rip_callback(int message, void *data)
+void
+rip_callback(int message, void *data)
 {
     RIP_MANAGER_INFO *info;
     ERROR_INFO *err;
@@ -228,7 +232,8 @@ void rip_callback(int message, void *data)
     }
 }
 
-void print_usage()
+void
+print_usage()
 {
     fprintf(stderr, "Usage: streamripper URL [OPTIONS]\n");
     fprintf(stderr, "Opts: -h             - Print this listing\n");
@@ -243,14 +248,12 @@ void print_usage()
     fprintf(stderr, "      -L file        - Create a relay playlist file\n");
     fprintf(stderr, "      -z             - Don't scan for free ports if base port is not avail\n");
     fprintf(stderr, "      -p url         - Use HTTP proxy server at <url>\n");
-    fprintf(stderr, "      -o always      - Always overwrite tracks in complete\n");
-    fprintf(stderr, "      -o never       - Never overwrite tracks in complete\n");
+    fprintf(stderr, "      -o (always|never|larger)    - When to tracks in complete\n");
     fprintf(stderr, "      -t             - Don't overwrite tracks in incomplete\n");
     fprintf(stderr, "      -c             - Don't auto-reconnect\n");
     fprintf(stderr, "      -l seconds     - Number of seconds to run, otherwise runs forever\n");
     fprintf(stderr, "      -M megabytes   - Stop ripping after this many megabytes\n");
     fprintf(stderr, "      -q [start]     - Add sequence number to output file\n");
-    fprintf(stderr, "      -i             - Don't add ID3 tags to output file\n");
     fprintf(stderr, "      -u useragent   - Use a different UserAgent than \"Streamripper\"\n");
     fprintf(stderr, "      -w rulefile    - Parse metadata using rules in file.\n");
     fprintf(stderr, "      -m timeout     - Number of seconds before force-closing stalled conn\n");
@@ -262,7 +265,20 @@ void print_usage()
     fprintf(stderr, "      -E command     - Run external command to fetch metadata\n");
     fprintf(stderr, "      --quiet        - Don't print ripping status to console\n");
     fprintf(stderr, "      --debug        - Save debugging trace\n");
-    fprintf(stderr, "      --xs_???       - Invoke splitpoint detection rules (see README/man page)\n");
+    fprintf(stderr, "ID3 opts (mp3/aac/nsv):  [The default behavior is adding ID3V2.3 only]\n");
+    fprintf(stderr, "      -i                           - Don't add any ID3 tags to output file\n");
+    fprintf(stderr, "      --with-id3v1                 - Add ID3V1 tags to output file\n");
+    fprintf(stderr, "      --without-id3v2              - Don't add ID3V2 tags to output file\n");
+    fprintf(stderr, "Splitpoint opts (mp3 only):\n");
+    fprintf(stderr, "      --xs-offset=num              - Shift relative to metadata (msec)\n");
+    fprintf(stderr, "      --xs-padding=num:num         - Add extra to prev:next track (msec)\n");
+    fprintf(stderr, "      --xs-search-window=num:num   - Search window relative to metadata (msec)\n");
+    fprintf(stderr, "      --xs-silence-length=num      - Expected length of silence (msec)\n");
+    fprintf(stderr, "Codeset opts:\n");
+    fprintf(stderr, "      --codeset-filesys=codeset    - Specify codeset for the file system\n");
+    fprintf(stderr, "      --codeset-id3=codeset        - Specify codeset for id3 tags\n");
+    fprintf(stderr, "      --codeset-metadata=codeset   - Specify codeset for metadata\n");
+    fprintf(stderr, "      --codeset-relay=codeset      - Specify codeset for the relay stream\n");
 }
 
 /* 
@@ -271,7 +287,8 @@ void print_usage()
  * port of it under Win32.. there probably is one, maybe i didn't look 
  * hard enough. 
  */
-void parse_arguments(int argc, char **argv)
+void
+parse_arguments(int argc, char **argv)
 {
     int i;
     char *c;
@@ -285,7 +302,7 @@ void parse_arguments(int argc, char **argv)
     set_rip_manager_options_defaults (&m_opt);
 
     // Get URL
-    strncpy(m_opt.url, argv[1], MAX_URL_LEN);
+    strncpy (m_opt.url, argv[1], MAX_URL_LEN);
 
     // Parse arguments
     for(i = 1; i < argc; i++) {
@@ -339,7 +356,9 @@ void parse_arguments(int argc, char **argv)
             exit(0);
 	    break;
 	case 'i':
-	    m_opt.flags ^= OPT_ADD_ID3;
+	    //	    m_opt.flags ^= OPT_ADD_ID3;
+	    OPT_FLAG_SET(m_opt.flags,OPT_ADD_ID3V1,0);
+	    OPT_FLAG_SET(m_opt.flags,OPT_ADD_ID3V2,0);
 	    break;
 	case 'I':
 	    i++;
@@ -473,44 +492,90 @@ parse_extended_options (char* rule)
     }
 
     /* Splitpoint options */
-    if (!strcmp(rule,"xs_none")) {
+    if ((!strcmp(rule,"xs-none"))
+	|| (!strcmp(rule,"xs_none"))) {
 	m_opt.sp_opt.xs = 0;
-	printf ("Disable silence detection");
+	debug_printf ("Disable silence detection");
 	return;
     }
-    if (1==sscanf(rule,"xs_min_volume=%d",&x)) {
+    if ((1==sscanf(rule,"xs-min-volume=%d",&x)) 
+	|| (1==sscanf(rule,"xs_min_volume=%d",&x))) {
 	m_opt.sp_opt.xs_min_volume = x;
-	printf ("Setting minimum volume to %d\n",x);
+	debug_printf ("Setting minimum volume to %d\n",x);
 	return;
     }
-    if (1==sscanf(rule,"xs_silence_length=%d",&x)) {
+    if ((1==sscanf(rule,"xs-silence-length=%d",&x))
+	|| (1==sscanf(rule,"xs_silence_length=%d",&x))) {
 	m_opt.sp_opt.xs_silence_length = x;
-	printf ("Setting silence length to %d\n",x);
+	debug_printf ("Setting silence length to %d\n",x);
 	return;
     }
-    if (2==sscanf(rule,"xs_search_window=%d:%d",&x,&y)) {
+    if ((2==sscanf(rule,"xs-search-window=%d:%d",&x,&y))
+	|| (2==sscanf(rule,"xs_search_window=%d:%d",&x,&y))) {
 	m_opt.sp_opt.xs_search_window_1 = x;
 	m_opt.sp_opt.xs_search_window_2 = y;
-	printf ("Setting search window to (%d:%d)\n",x,y);
+	debug_printf ("Setting search window to (%d:%d)\n",x,y);
 	return;
     }
-    if (1==sscanf(rule,"xs_offset=%d",&x)) {
+    if ((1==sscanf(rule,"xs-offset=%d",&x))
+	|| (1==sscanf(rule,"xs_offset=%d",&x))) {
 	m_opt.sp_opt.xs_offset = x;
-	printf ("Setting silence offset to %d\n",x);
+	debug_printf ("Setting silence offset to %d\n",x);
 	return;
     }
-    if (2==sscanf(rule,"xs_padding=%d:%d",&x,&y)) {
+    if ((2==sscanf(rule,"xs-padding=%d:%d",&x,&y))
+	|| (2==sscanf(rule,"xs_padding=%d:%d",&x,&y))) {
 	m_opt.sp_opt.xs_padding_1 = x;
 	m_opt.sp_opt.xs_padding_2 = y;
-	printf ("Setting file output padding to (%d:%d)\n",x,y);
+	debug_printf ("Setting file output padding to (%d:%d)\n",x,y);
+	return;
+    }
+
+    /* id3 options */
+    if (!strcmp(rule,"with-id3v2")) {
+	OPT_FLAG_SET(m_opt.flags,OPT_ADD_ID3V2,1);
+	return;
+    }
+    if (!strcmp(rule,"without-id3v2")) {
+	OPT_FLAG_SET(m_opt.flags,OPT_ADD_ID3V2,0);
+	return;
+    }
+    if (!strcmp(rule,"with-id3v1")) {
+	OPT_FLAG_SET(m_opt.flags,OPT_ADD_ID3V1,1);
+	return;
+    }
+    if (!strcmp(rule,"without-id3v1")) {
+	OPT_FLAG_SET(m_opt.flags,OPT_ADD_ID3V1,0);
 	return;
     }
 
     /* codeset options */
-    x = strlen("codeset=");
-    if (!strncmp(rule,"codeset=",x)) {
-	m_opt.cs_opt.codeset = &rule[x];
-	printf ("Setting codeset to %s\n",m_opt.cs_opt.codeset);
+    x = strlen("codeset-filesys=");
+    if (!strncmp(rule,"codeset-filesys=",x)) {
+	strncpy (m_opt.cs_opt.codeset_filesys, &rule[x], MAX_CODESET_STRING);
+	debug_printf ("Setting filesys codeset to %s\n",
+		      m_opt.cs_opt.codeset_filesys);
+	return;
+    }
+    x = strlen("codeset-id3=");
+    if (!strncmp(rule,"codeset-id3=",x)) {
+	strncpy (m_opt.cs_opt.codeset_id3, &rule[x], MAX_CODESET_STRING);
+	debug_printf ("Setting id3 codeset to %s\n",
+		      m_opt.cs_opt.codeset_id3);
+	return;
+    }
+    x = strlen("codeset-metadata=");
+    if (!strncmp(rule,"codeset-metadata=",x)) {
+	strncpy (m_opt.cs_opt.codeset_metadata, &rule[x], MAX_CODESET_STRING);
+	debug_printf ("Setting metadata codeset to %s\n",
+		      m_opt.cs_opt.codeset_metadata);
+	return;
+    }
+    x = strlen("codeset-relay=");
+    if (!strncmp(rule,"codeset-relay=",x)) {
+	strncpy (m_opt.cs_opt.codeset_relay, &rule[x], MAX_CODESET_STRING);
+	debug_printf ("Setting relay codeset to %s\n",
+		      m_opt.cs_opt.codeset_relay);
 	return;
     }
 
